@@ -454,6 +454,7 @@ void readinput(lprec *lp)
       free(thp->name);
       free(thp); /* free memory when data has been read */
     }
+	Hash_tab->table[i] = NULL;
   }
   lp->col_end[index] = nn_ind; 
 
@@ -607,8 +608,8 @@ lprec *read_lp_file(FILE *input, short verbose, nstring lp_name)
   lp->eta_alloc   = INITIAL_MAT_SIZE;
   lp->max_num_inv = DEFNUMINV;
 
-  CALLOC(lp->eta_value,   INITIAL_MAT_SIZE);
-  CALLOC(lp->eta_row_nr,  INITIAL_MAT_SIZE);
+  CALLOC(lp->eta_value,   INITIAL_MAT_SIZE + 1);
+  CALLOC(lp->eta_row_nr,  INITIAL_MAT_SIZE + 1);
   CALLOC(lp->eta_col_end, Rows + lp->max_num_inv + 1);
 
   lp->iter       = 0;
@@ -650,5 +651,7 @@ lprec *read_lp_file(FILE *input, short verbose, nstring lp_name)
     free(cp);
   }
 
+  free_hash_table(Hash_tab);
+
   return(lp); 
 }
