@@ -123,25 +123,26 @@ static short isvalid(lprec *lp)
   return(TRUE);
 } 
 
-static void resize_eta(lprec *lp)
+static void resize_eta(lprec *lp, int min_size)
 {
-  lp->eta_alloc *= 1.5;
-  REALLOC(lp->eta_value, lp->eta_alloc);
-  REALLOC(lp->eta_row_nr, lp->eta_alloc);
-  /* fprintf(stderr, "resized eta to size %d\n", lp->eta_alloc); */
+  while(lp->eta_alloc <= min_size)
+    lp->eta_alloc *= 1.5;
+  /* fprintf(stderr, "resizing eta to size %d\n", lp->eta_alloc); */
+  REALLOC(lp->eta_value, lp->eta_alloc + 1);
+  REALLOC(lp->eta_row_nr, lp->eta_alloc + 1);
 } /* resize_eta */
 
-
 static void condensecol(lprec *lp,
 			int row_nr,
 			REAL *pcol)
 {
-  int i, elnr;
+  int i, elnr, min_size;
   
   elnr = lp->eta_col_end[lp->eta_size];
 
-  if(elnr + lp->rows + 2 >= lp->eta_alloc) /* maximum local growth of Eta */
-    resize_eta(lp);
+  min_size = elnr + lp->rows + 2;
+  if(min_size >= lp->eta_alloc) /* maximum local growth of Eta */
+    resize_eta(lp, min_size);
 
   for(i = 0; i <= lp->rows; i++)
     if(i != row_nr && pcol[i] != 0) {
@@ -225,7 +226,7 @@ static void minoriteration(lprec *lp,
     lp->eta_value[elnr] = -Extrad;
     elnr++;
     if(elnr >= lp->eta_alloc)
-      resize_eta(lp);
+      resize_eta(lp, elnr);
   }
 
   for(j = lp->col_end[colnr - 1] ; j < lp->col_end[colnr]; j++) {
@@ -238,7 +239,7 @@ static void minoriteration(lprec *lp,
       lp->eta_value[elnr] = lp->mat[j].value;
       elnr++;
       if(elnr >= lp->eta_alloc)
-	resize_eta(lp);
+	resize_eta(lp, elnr);
     }
     else
       piv = lp->mat[j].value;
@@ -922,6 +923,9 @@ static int solvelp(lprec *lp)
     for(i = 1; i <= lp->rows; i++)
       drow[i] = 0;
 
+	/* fix according to Joerg Herbers */
+	btran(lp, drow);
+
     Extrad = 0;
 
     for(i = 1; i <= lp->columns; i++) {
@@ -1281,7 +1285,7 @@ static int milpsolve(lprec *lp,
 
     /* transform to all lower bounds zero */
     for(i = 1; i <= lp->columns; i++)
-      if((theta = lp->lowbo[lp->rows + i] != 0)) {
+      if((theta = lp->lowbo[lp->rows + i]) != 0) {
 	if(lp->upbo[lp->rows + i] < lp->infinite)
 	  lp->upbo[lp->rows + i] -= theta;
 	for(j = lp->col_end[i - 1]; j < lp->col_end[i]; j++)
